# create rsyslog.conf

define base::syslog::config::rsyslog(
    $ensure          = 'present',
    $source          = undef,
    $owner           = 'root',
    $group           = 'root',
    $mode            = '0644',
    $replace         = true,
    $use_syslog_conf = true,
) {
  if $source {
    $template = undef
  } else {
    if $use_syslog_conf {
      $template = template('base/syslog/rsyslog.conf.erb')
    } else {
      $template = template('base/syslog/rsyslog-nosyslog.conf.erb')
      file {
        '/etc/syslog.conf':
          ensure => absent;
        '/etc/rsyslog.d/90-local.conf':
          ensure  => present,
          source  => 'puppet:///modules/base/syslog/etc/rsyslog.d/90-local.conf';
          owner   => $owner,
          group   => $group,
          mode    => $mode;
      }
    }
  }
  file { $name:
    ensure  => $ensure,
    source  => $source,
    content => $template,
    owner   => $owner,
    group   => $group,
    mode    => $mode,
    replace => $replace,
    notify  => Service['syslog'],
  }
}
